@@ -1,21 +1,10 @@
-try:
-    import importlib.resources as pkg_resources
-except ImportError:
-    # Try backported to PY<37 `importlib_resources`.
-    # We support down to Python 3.6 so this is needed to prevent breaking change
-    import importlib_resources as pkg_resources
-import linter_configs
 import logging
 import json
 import os
 import requests
 import sys
 import yaml
-from typing import Optional
-
-from yamllint.cli import show_problems
-from yamllint.config import YamlLintConfig
-from yamllint import linter
+from typing import Optional, Dict
 
 EXPECTED_TF_CONFIG_FILE_NAMES = ["tdfconfig.yml", "tdfconfig.yaml", "validate_configs.yaml", "commit_configs.yaml"]
 TRANSFORM_API_URL = "https://web-api.prod.transformdata.io"
@@ -58,22 +47,9 @@ def read_config_files(config_dir: str):
     return results
 
 
-def lint_transform_configs(config_dir: str):
-    """Run the python yamllinter on all metric configs"""
-    linter_config = pkg_resources.read_text(linter_configs, "yaml_linter_config.yaml")
-    conf = YamlLintConfig(content=linter_config)
-    max_level = 0
-    for _, fdata in read_config_files(config_dir).items():
-        problems = linter.run(fdata, conf, "")
-        level = show_problems(problems, "stdin", args_format="colored", no_warn=False)
-        max_level = max(max_level, level)
-    if max_level == linter.PROBLEM_LEVELS["error"]:
-        raise Exception("Python yamllint linter failed. See console output above for errors")
-
-
 def upload_configs(  # noqa: D
     mode: str,
-    api_key: str,
+    auth_header: Dict[str, str],
     repo: Optional[str] = None,
     branch: Optional[str] = None,
     commit: Optional[str] = None,
@@ -82,14 +58,11 @@ def upload_configs(  # noqa: D
 ) -> requests.Response:
 
     config_dir_to_use = config_dir or "."
-    # run python yaml linter in order to assert configs are following correct yaml syntax.
-    # this is to avoid adhoc debugging for config writers later.
-    lint_transform_configs(config_dir_to_use)
 
     yaml_files = read_config_files(config_dir_to_use)
     results = {"yaml_files": yaml_files}
     logger.info(f"Files to upload: {yaml_files.keys()}")
-    headers = {"Content-Type": "application/json", "Authorization": f"X-Api-Key {api_key}"}
+    headers = {**{"Content-Type": "application/json"}, **auth_header}
     url = api_url or TRANSFORM_API_URL
     verify = url.startswith("https")
 
@@ -148,6 +121,7 @@ if __name__ == "__main__":
     if TRANSFORM_CONFIG_DIR:
         TRANFSFORM_CONFIG_DIR = TRANSFORM_CONFIG_DIR.lstrip().rstrip()
     TRANSFORM_API_KEY = os.environ["TRANSFORM_API_KEY"].lstrip().rstrip()  # fail if TRANSFORM_API_KEY not present
+    auth_header = {"Authorization": f"X-Api-Key {TRANSFORM_API_KEY}"}
 
-    upload_configs(mode, TRANSFORM_API_KEY, REPO, BRANCH, COMMIT, TRANSFORM_CONFIG_DIR, API_URL)
+    upload_configs(mode, auth_header, REPO, BRANCH, COMMIT, TRANSFORM_CONFIG_DIR, API_URL)
     print("success")
